<?php
/*
Plugin Name: LeadMaster - post gravity form to http request
Plugin URI: 
Description: post data gravity to your web
Version: 1.0
Author: LeadMaster
Author Email: andy@leadmaster.com
License:
*/


if ( !defined( 'GRAVITY_HTTP_PATH' ) ) define( 'GRAVITY_HTTP_PATH',   plugin_dir_path( __FILE__ ) . 'inc/' );
if ( !defined( 'GRAVITY_HTTP_URL' ) ) define( 'GRAVITY_HTTP_URL',   plugin_dir_url( __FILE__ ) . 'inc/' );

class GravityHTTPRequest {

	
	const name = 'Http request';
	const slug = 'gravity_http_request';

	function __construct() {
		add_filter('gform_form_settings_menu', array($this, 'gravity_http_settings_menu'));

		add_action('gform_form_settings_page_'.self::slug, array($this, 'gravity_http_settings_page'));

		add_action('admin_enqueue_scripts', array($this, 'register_scripts_and_styles'));

		add_action('gform_after_submission', array($this, 'gravity_http_post_data'), 10, 2);
	}

	function gravity_http_post_data($entry, $form) {
		if ($form['http_request_settings']['http_request_active']):
			$post_url = $form['http_request_settings']['form_http_url'];
 			$request = new WP_Http();

		foreach ( $form['fields'] as $field ) {
			if ( $field['inputs'] ) {

				if ($field['http_output'] === 'map') {
					$serializeMap = [];

					foreach ($field['inputs'] as $input) {

						$id = (string)$input['id'];
						$post_body[$input['http_map']] = $entry[$id];
						// code added by bhavin shah for checkbox
						$serializeMap[] = $entry[$id];
						// code end by bhavin shah for checkbox
					}
					// code added by bhavin shah for checkbox
					if($field['type']==='checkbox'){
						$post_body[$field['http_map']]=implode(',', $serializeMap);
					}
					
					// code End by bhavin shah for checkbox


				} elseif ($field['http_output'] === 'serialize') {

                    $serialize = [];

					foreach ($field['inputs'] as $input) {

						$id =  (string)$input['id'];

						$serialize[] = $entry[$id];

					}

					$post_body[$field['http_map']] = json_encode($serialize);

					// code added by bhavin shah for checkbox
					if($field['type']==='checkbox'){
						$post_body[$field['http_map']]=implode(',', $serialize);
					}
					
					// code End by bhavin shah for checkbox
				}

			} else {

				$post_body[$field['http_map']] = $entry[$field['id']];

			}

		}

		if ($form['http_request_settings']['http_request_type'] === 'post_request') {
			$response = $request->request( $post_url, array( 'method' => 'POST', 'body' => $post_body, 'sslverify' => false ) );
			


		} elseif ($form['http_request_settings']['http_request_type'] === 'get_request') {

			$response = $request->request( $post_url, array( 'method' => 'GET', 'body' => $post_body) );

		}

		if (is_wp_error($response)) {

			$error = $response->get_error_message();

			error_log("WP Error:" . $error, 0);

		}

		else {

			$log = $response['body'];

			error_log("Form:" . $log, 0);

		}

		endif;

	}


	// add a custom menu item to the Form Settings page menu
	function gravity_http_settings_menu($menu_items) {

		$menu_items[] = array(
			'name' => self::slug,
			'label' => self::name
		);

		return $menu_items;
	}


	// handle displaying content for our custom menu when selected
	function gravity_http_settings_page() {

		//see if there is a form id in the querystring
		$form_id = RGForms::get("id");

		$form = GFAPI::get_form($form_id);

		if ( ! empty( $_POST ) &&  check_admin_referer('gforms_save_http_settings', 'gforms_save_http_settings') ) {

			$form['http_request_settings']['form_http_url'] = rgpost('form_http_url');
			$form['http_request_settings']['http_request_type'] = rgpost('form_request_type');
			$form['http_request_settings']['date_updated'] = rgpost('date_updated');
			$form['http_request_settings']['http_request_active'] = rgpost('http_request_active');

			$i=0;
									//echo "<pre>";print_r($form['fields']);exit;

			foreach ($form['fields'] as $field) {

				if ($field['inputs']) {

					$form['fields'][$i]->http_map = rgpost('field_'.$field['id'].'_map');

					$form['fields'][$i]->http_output = rgpost('field_'.$field['id'].'_serialize');


					$k=0;
					foreach ($field['inputs'] as $input) {

						$input_id = str_replace('.', '_', $input['id']);

						$form['fields'][$i]->inputs[$k]['http_map'] = rgpost('field_'.$input_id.'_map');

						$k++;
					}




				} else {

					$form['fields'][$i]->http_map = rgpost('field_'.$field['id'].'_map');


					if ($field['choices']) {

						$form['fields'][$i]->value_output = rgpost('field_'.$field['id'].'_value_output');

					}

				}


				$i++;
			}
//echo "<pre>";print_r($form);exit;
			$result = GFAPI::update_form($form);

		}


		GFFormSettings::page_header();

		include_once(GRAVITY_HTTP_PATH.'settings-screen.php');
		
		GFFormSettings::page_footer();

	}



	/**
	 * Registers and enqueues stylesheets for the administration panel and the
	 * public facing site.
	 */
	function register_scripts_and_styles() {
		if ( is_admin() ) {

			wp_register_style('gravity_http_styles', GRAVITY_HTTP_URL . 'css/plugin-admin.css');
			wp_enqueue_style('gravity_http_styles');

		} else {

		} // end if/else
	} // end register_scripts_and_styles

} // end class

if (class_exists('GFForms')) {

	new GravityHTTPRequest();

}


?>